from nonebot.plugin import PluginMetadata
from .calc import calc_rank , calc_highattr

__version__ = "0.1.3"
__plugin_meta__ = PluginMetadata(
    name="学园偶像大师算分插件",
    description="学院偶像大师算分",
    usage="在群聊中输入“算分”与三维属性或“算属性”",

    type="application",
    # 发布必填，当前有效类型有：`library`（为其他插件编写提供功能），`application`（向机器人用户提供功能）。

    homepage="https://github.com/ikarosf/nonebot_plugin_gakuenImasCalculator",
    # 发布必填。

    config=None,
    # 插件配置项类，如无需配置可不填写。

    supported_adapters=None,
    # 支持的适配器集合，其中 `~` 在此处代表前缀 `nonebot.adapters.`，其余适配器亦按此格式填写。
    # 若插件可以保证兼容所有适配器（即仅使用基本适配器功能）可不填写，否则应该列出插件支持的适配器。
)


from math import ceil
from decimal import Decimal
from typing import List

indextrans = ["红","蓝","黄"]

def _caclattr2(attrlist , attrbonuslist , choose):
    #choose 165 all 145
    addattrlist = [145,145,145]
    addattrlist[choose] += 165
    addattrlist =  [x * (1+y) for x, y in zip(addattrlist, attrbonuslist)]
    resultlist =  [x + y for x, y in zip(attrlist, addattrlist)]
    return resultlist

def _caclattr1(attrlist , attrbonuslist , examsplist , choose):
    if examsplist is None:
        raise ValueError("examsplist长度错误")
    #150 sp 220
    addattr = 220 if examsplist[choose] == 1 else 150
    addattr += addattr * attrbonuslist[choose]
    resultlist = attrlist.copy()
    resultlist[choose] += addattr
    return resultlist

    

def _caclattr(stage , attrlist , attrbonuslist , examsplist):
    if len(attrlist) < 3 or len(attrbonuslist) < 3:
        raise ValueError("attrlist/attrbonuslist长度错误")
    
    attrbonuslist =  [number / 100 for number in attrbonuslist]
    
    templist = []
    resultlist = []
    if stage == 1:
        for i in range(3):
            templist.append(
                _caclattr1(attrlist , attrbonuslist , examsplist , i)
                )
    else:
        templist.append(attrlist)

    for i in range(3):
        for j in range(3):
            if(len(templist) <= i):
                break
            resultlist.append((i,j,
                              _caclattr2(templist[i],attrbonuslist,j)
            ))
            
    return resultlist
    
def printallitem(resultlist):
    messgae = ""
    for item in resultlist:
        sumattr = sum(min(thisattr, 1470) for thisattr in item[2]) + 90
        
        if len(resultlist) == 3:
            messgae += "选择 " + indextrans[item[1]] + "："
        else:
            messgae += "选择 " + indextrans[item[0]] + " " + indextrans[item[1]] + "："

        sumattr = sum(min(thisattr, 1470) for thisattr in item[2]) + 90
        messgae += "属性为" + str(min(1470,int(item[2][0]))) + "+" + str(min(1470,int(item[2][1]))) + "+" + str(min(1470,int(item[2][2]))) + "+90=" + str(int(sumattr)) + "\n"

    print(messgae)


def printmaxitem(resultlist):
    maxattr = 0
    maxitem = None
    for item in resultlist:
        sumattr = sum(min(thisattr, 1470) for thisattr in item[2])
        if sumattr > maxattr:
            maxattr = sumattr
            maxitem = item

    messgae = ""
    if len(resultlist) == 3:
        messgae += "选择 " + indextrans[maxitem[1]] + "："
    else:
        messgae += "选择 " + indextrans[maxitem[0]] + " " + indextrans[maxitem[1]] + "："

    sumattr = sum(min(thisattr, 1470) for thisattr in maxitem[2]) + 90
    messgae += "属性为" + str(min(1470,int(maxitem[2][0]))) + "+" + str(min(1470,int(maxitem[2][1]))) + "+" + str(min(1470,int(maxitem[2][2]))) + "+90=" + str(int(sumattr)) + "\n"
    print(messgae)

if __name__ == "__main__":
    stage = 1
    attrlist = [800,900,1000]
    attrbonuslist = [10,25,35]
    examsplist = [1 , 1 , 1]
    resultlist = _caclattr(stage , attrlist , attrbonuslist , examsplist)
    printmaxitem(resultlist)



    printallitem(resultlist)


from nonebot.adapters import Bot, Message, Event
from nonebot.plugin.on import on_command
from nonebot.params import Arg, CommandArg
from nonebot.matcher import Matcher
from nonebot.typing import T_State
from math import ceil
from decimal import Decimal
from typing import List
from .OCRattrs import getattrs
from .calcfun import _calc_rank , attrmaxMap

calc_rank = on_command(
    "算分",
    aliases={},
    priority=20,
    block=True,
)

@calc_rank.handle()
async def _(bot: Bot, event: Event , matcher: Matcher, state: T_State, cmd_arg: Message = CommandArg()):
    if cmd_arg:
        state["calcrankattr"] = cmd_arg


@calc_rank.got("calcrankattr",prompt="请输入三维数字或图片")
async def _(bot: Bot, event: Event , matcher: Matcher, state: T_State , cmd_arg: Message = Arg("calcrankattr")):
    for segment in cmd_arg:
        if segment.type == "image":
            args = getattrs(segment.data["url"])
            if(len(args) != 3):
                await matcher.finish("无法识别的图片")
            break
    else:
        args: List[str] = cmd_arg.extract_plain_text().strip().split()
        if(len(args) != 3):
            await matcher.finish("参数错误，请输入角色三维")

    VO = Decimal(args[0])
    DI = Decimal(args[1])
    VI = Decimal(args[2])

    onlyh = False
    onlym = False
    retmessage = ""

    if VO <= attrmaxMap["h"] - 30 and DI <= attrmaxMap["h"] - 30 and VI <= attrmaxMap["h"] - 30:
        onlyh = True

    if VO > attrmaxMap["h"] or DI > attrmaxMap["h"] or VI > attrmaxMap["h"]:
        onlym = True

    if not onlym:
        if not onlyh:
            retmessage += "在hard难度下：\n"
        retmessage += _calc_rank(VO,DI,VI,attrmaxMap["h"])

    if not onlyh:
        if not onlym:
            retmessage += "在master难度下：\n"
        retmessage += _calc_rank(VO,DI,VI,attrmaxMap["m"])

    await matcher.finish(retmessage)





calc_highattr = on_command(
    "算属性",
    aliases={},
    priority=20,
    block=True,
)

indextrans = ["红","蓝","黄"]

def _caclattr2(attrlist , attrbonuslist , choose):
    #choose 165 all 145
    addattrlist = [145,145,145]
    addattrlist[choose] += 165
    addattrlist =  [x * (1+y) for x, y in zip(addattrlist, attrbonuslist)]
    resultlist =  [x + y for x, y in zip(attrlist, addattrlist)]
    return resultlist

def _caclattr1(attrlist , attrbonuslist , examsplist , choose , examLv):
    if examsplist is None:
        raise ValueError("examsplist长度错误")
    #h:150 sp 220
    #m:210 sp 280
    if examLv == "h":
        addattr = 220 if examsplist[choose] == 1 else 150
    else:
        addattr = 280 if examsplist[choose] == 1 else 210
    addattr += addattr * attrbonuslist[choose]
    resultlist = attrlist.copy()
    resultlist[choose] += addattr
    return resultlist

    

def _caclattr(stage , attrlist , attrbonuslist , examsplist, examLv):
    if len(attrlist) < 3 or len(attrbonuslist) < 3:
        raise ValueError("attrlist/attrbonuslist长度错误")
    
    attrbonuslist =  [number / 100 for number in attrbonuslist]
    
    templist = []
    resultlist = []
    if stage == 1:
        for i in range(3):
            templist.append(
                _caclattr1(attrlist , attrbonuslist , examsplist , i , examLv)
                )
    else:
        templist.append(attrlist)

    for i in range(3):
        for j in range(3):
            if(len(templist) <= i):
                break
            resultlist.append((i,j,
                              _caclattr2(templist[i],attrbonuslist,j)
            ))
            
    return resultlist
    
def printallitem(resultlist,_attrMAX):
    messgae = ""
    for item in resultlist:
        sumattr = sum(min(thisattr, _attrMAX) for thisattr in item[2]) + 90
        
        if len(resultlist) == 3:
            messgae += "选择 " + indextrans[item[1]] + "："
        else:
            messgae += "选择 " + indextrans[item[0]] + " " + indextrans[item[1]] + "："

        sumattr = sum(min(thisattr, _attrMAX) for thisattr in item[2]) + 90
        messgae += "属性为" + str(min(_attrMAX,int(item[2][0]))) + "+" + str(min(_attrMAX,int(item[2][1]))) + "+" + str(min(_attrMAX,int(item[2][2]))) + "+90=" + str(int(sumattr)) + "\n"

    return messgae


def printmaxitem(resultlist,_attrMAX):
    maxattr = 0
    maxitem = None
    for item in resultlist:
        sumattr = sum(min(thisattr, _attrMAX) for thisattr in item[2])
        if sumattr > maxattr:
            maxattr = sumattr
            maxitem = item

    messgae = ""
    if len(resultlist) == 3:
        messgae += "选择 " + indextrans[maxitem[1]] + "："
    else:
        messgae += "选择 " + indextrans[maxitem[0]] + " " + indextrans[maxitem[1]] + "："

    sumattr = sum(min(thisattr, _attrMAX) for thisattr in maxitem[2]) + 90
    messgae += "属性为" + str(min(_attrMAX,int(maxitem[2][0]))) + "+" + str(min(_attrMAX,int(maxitem[2][1]))) + "+" + str(min(_attrMAX,int(maxitem[2][2]))) + "+90=" + str(int(sumattr)) + "\n"
    return messgae



@calc_highattr.handle()
async def _(bot: Bot, event: Event , matcher: Matcher, cmd_arg: Message = CommandArg()):
    pass

@calc_highattr.got("examstage",prompt="请输入数字指定场景：1、最后一次普通训练或者sp训练 2、期末前追训")
async def _(bot: Bot, event: Event , matcher: Matcher, state: T_State , cmd_arg: Message = Arg("examstage")):
    args: List[str] = cmd_arg.extract_plain_text().strip().split()

    if len(args) == 1:
        try:
            myarg = int(args[0])
        except:
            await matcher.finish("参数错误，算属性结束！examstage1")
        if myarg == 1 :
            state["examstage1"] = 1
        elif myarg == 2 :
            state["examstage1"] = 2
            state["examstagesp"] = -1
        else:
            await matcher.finish("参数错误，算属性结束！examstage2")
    else:
        await matcher.finish("参数错误，算属性结束！examstage3")


@calc_highattr.got("examstLv",prompt="请输入数字指定难度：1、hard难度 2、master难度")
async def _(bot: Bot, event: Event , matcher: Matcher, state: T_State , cmd_arg: Message = Arg("examstLv")):
    args: List[str] = cmd_arg.extract_plain_text().strip().split()

    if len(args) == 1:
        try:
            myarg = int(args[0])
        except:
            await matcher.finish("参数错误，算属性结束！examstLv1")
        if myarg == 1 :
            state["examstLv"] = "h"
        elif myarg == 2 :
            state["examstLv"] = "m"
        else:
            await matcher.finish("参数错误，算属性结束！examstLv2")
    else:
        await matcher.finish("参数错误，算属性结束！examstLv3")

@calc_highattr.got("examstagesp",prompt="请输入3训练是否有sp，1代表有0代表没有，以空格分割，如1 0 0")
async def _(bot: Bot, event: Event , matcher: Matcher, state: T_State , cmd_arg: Message = Arg("examstagesp")):
    args: List[str] = cmd_arg.extract_plain_text().strip().split()

    if state["examstage1"] == 2:
        return

    if(len(args) != 3):
        await matcher.finish("参数错误，算属性结束！examstagesp1")

    try:
        state["examstagesp"] = [int(x) for x in args]
    except:
        await matcher.finish("参数错误，算属性结束！examstagesp2")

@calc_highattr.got("examattr",prompt="请输入当前三维属性红蓝黄，以空格分割")
async def _(bot: Bot, event: Event , matcher: Matcher, state: T_State , cmd_arg: Message = Arg("examattr")):
    args: List[str] = cmd_arg.extract_plain_text().strip().split()

    if(len(args) != 3):
        await matcher.finish("参数错误，算属性结束！examattr1")

    try:
        state["attrlist"] = [int(args[0]),int(args[1]),int(args[2])]
    except:
        await matcher.finish("参数错误，算属性结束！examattr2")

@calc_highattr.got("examattrbonus" ,prompt="请输入三属性额外增加百分比（省略百分号），以空格分割")
async def _(bot: Bot, event: Event , matcher: Matcher, state: T_State , cmd_arg: Message = Arg("examattrbonus")):
    args: List[str] = cmd_arg.extract_plain_text().strip().split()

    if(len(args) != 3):
        await matcher.finish("参数错误，算属性结束！examattrbonus1")

    try:
        state["attrbonuslist"] = [float(args[0]),float(args[1]),float(args[2])]
    except:
        await matcher.finish("参数错误，算属性结束！examattrbonus2")

    resultlist = _caclattr(state["examstage1"],state["attrlist"],state["attrbonuslist"],state["examstagesp"],state["examstLv"])
    message = printmaxitem(resultlist,attrmaxMap[state["examstLv"]]-30)
    state["resultlist"] = resultlist
    await matcher.send(message + "输入1查看详细属性，其他输入会结束本次计算")

@calc_highattr.got("detail")
async def _(bot: Bot, event: Event , matcher: Matcher, state: T_State , cmd_arg: Message = Arg("detail")):
    args = cmd_arg.extract_plain_text().strip()
    if args != "1":
        await matcher.finish("已结束！")

    message = printallitem(state["resultlist"],attrmaxMap[state["examstLv"]]-30)

    await matcher.finish(message)


from math import ceil
from decimal import Decimal

attrmaxMap = {
    "h":1500,
    "m":1800
}

def _calc_rank(vo,di,vi,attrmax):
    _attrmax = attrmax - 30
    shuxingyichuFLAG = False
    VO = Decimal(vo)
    DI = Decimal(di)
    VI = Decimal(vi)

    if VO > _attrmax:
        VO = Decimal(_attrmax)
        shuxingyichuFLAG = True
    if DI > _attrmax:
        DI = Decimal(_attrmax)
        shuxingyichuFLAG = True
    if VI > _attrmax:
        VI = Decimal(_attrmax)
        shuxingyichuFLAG = True
    
    shuxingfen = int((VO + DI + VI + Decimal(90))* Decimal(str(2.3)))
    mingcifen = 1700

    '''
    <5000 max:1500
    <10000 2250
    <20000 3050
    <30000 3450
    <40000 3650
    <50000 3750
    
    '''
    A_rank = 10000
    Ap_rank = 11500
    S_rank = 13000
    Sp_rank = 14500
    biaoxianfenlist = [1500,2250,3050,3450,3650,3750]

    juliA = A_rank - shuxingfen - mingcifen
    juliAp = Ap_rank - shuxingfen - mingcifen
    juliS = S_rank - shuxingfen - mingcifen
    juliSp = Sp_rank - shuxingfen - mingcifen

    if juliA <= 0:
        Ascore = 0
    elif juliA <= 1500:
        Ascore = ceil(juliA / 0.3)
    elif juliA <= 2250:
        Ascore = ceil((juliA - 750 )/ 0.15)
    elif juliA <= 3050:
        Ascore = ceil((juliA - 1450 )/ 0.08)
    elif juliA <= 3450:
        Ascore = ceil((juliA - 2250 )/ 0.04)
    elif juliA <= 3650:
        Ascore = ceil((juliA - 2850 )/ 0.02)
    elif juliA <= 3950:
        Ascore = ceil((juliA - 3250 )/ 0.01)
    else:
        Ascore = -1

    if juliAp <= 0:
        Apscore = 0
    elif juliAp <= 1500:
        Apscore = ceil(juliAp / 0.3)
    elif juliAp <= 2250:
        Apscore = ceil((juliAp - 750 )/ 0.15)
    elif juliAp <= 3050:
        Apscore = ceil((juliAp - 1450 )/ 0.08)
    elif juliAp <= 3450:
        Apscore = ceil((juliAp - 2250 )/ 0.04)
    elif juliAp <= 3650:
        Apscore = ceil((juliAp - 2850 )/ 0.02)
    elif juliAp <= 3950:
        Apscore = ceil((juliAp - 3250 )/ 0.01)
    else:
        Apscore = -1

    if juliS <= 0:
        Sscore = 0
    elif juliS <= 1500:
        Sscore = ceil(juliS / 0.3)
    elif juliS <= 2250:
        Sscore = ceil((juliS - 750 )/ 0.15)
    elif juliS <= 3050:
        Sscore = ceil((juliS - 1450 )/ 0.08)
    elif juliS <= 3450:
        Sscore = ceil((juliS - 2250 )/ 0.04)
    elif juliS <= 3650:
        Sscore = ceil((juliS - 2850 )/ 0.02)
    elif juliS <= 3950:
        Sscore = ceil((juliS - 3250 )/ 0.01)
    else:
        Sscore = -1

    if juliSp <= 0:
        Spscore = 0
    elif juliSp <= 1500:
        Spscore = ceil(juliSp / 0.3)
    elif juliSp <= 2250:
        Spscore = ceil((juliSp - 750 )/ 0.15)
    elif juliSp <= 3050:
        Spscore = ceil((juliSp - 1450 )/ 0.08)
    elif juliSp <= 3450:
        Spscore = ceil((juliSp - 2250 )/ 0.04)
    elif juliSp <= 3650:
        Spscore = ceil((juliSp - 2850 )/ 0.02)
    elif juliSp <= 3950:
        Spscore = ceil((juliSp - 3250 )/ 0.01)
    else:
        Spscore = -1

    retmessage = ""
    if shuxingyichuFLAG:
        retmessage += "属性溢出了，单属性最高只计算" + str(attrmax) + "\n"
    retmessage += "你的属性总合为： " + str(VO) + " + " + str(DI) + " + " + str(VI) + " + 90 = " + str((VO + DI + VI + Decimal(90))) + "\n"
    if Ascore == -1:
        retmessage += "杂鱼连A都不可能到的，杂鱼杂鱼"
        return retmessage
    elif Ascore == 0:
        retmessage += "已经稳A了\n"
    else:
        retmessage += "A评价需要获得" + str(Ascore) + "分\n"

    if Apscore == -1:
        retmessage += "想拿到A+就做梦吧"
        return retmessage
    elif Apscore == 0:
        retmessage += "一把抓住A+，顷刻炼化！\n"
    else:
        retmessage += "A+评价需要获得" + str(Apscore) + "分\n"

    if Sscore == -1:
        retmessage += "S是你得不到的"
        return retmessage
    elif Sscore == 0:
        retmessage += "已经稳S了???你开了吧\n"
    else:
        retmessage += "S评价需要获得" + str(Sscore) + "分\n"

    if Spscore == -1:
        retmessage += ""
    elif Spscore == 0:
        retmessage += "已经稳S+了???你这是在做梦吧\n"
    else:
        retmessage += "S+评价需要获得" + str(Spscore) + "分\n"
    return retmessage


import cv2
import numpy as np
import easyocr
import os
from .downloadpic import getpic , getpic2

# 读取大图片和图标图片
current_directory = os.path.dirname(os.path.abspath(__file__))

red_image = cv2.imread(os.path.join(current_directory,'red.png'), cv2.IMREAD_UNCHANGED)
blue_image = cv2.imread(os.path.join(current_directory,'blue.png'), cv2.IMREAD_UNCHANGED)
yellow_image = cv2.imread(os.path.join(current_directory,'yellow.png'), cv2.IMREAD_UNCHANGED)
reader = easyocr.Reader([])
# 将图片转换为灰度图

# 如果图标图像有透明通道，我们需要只使用 BGR 通道
if red_image.shape[2] == 4:
    red_image = cv2.cvtColor(red_image, cv2.COLOR_BGRA2BGR)
if blue_image.shape[2] == 4:
    blue_image = cv2.cvtColor(blue_image, cv2.COLOR_BGRA2BGR)
if yellow_image.shape[2] == 4:
    yellow_image = cv2.cvtColor(yellow_image, cv2.COLOR_BGRA2BGR)

def getattrs(url):
    ret = []
    large_image = getpic(url)
    if large_image is None:
        return []
    if large_image.shape[2] == 4:
        large_image = cv2.cvtColor(large_image, cv2.COLOR_BGRA2BGR)

    best_match_scale = None
    for icon_image in [red_image,blue_image,yellow_image]:
        # 创建一个空变量来记录最佳匹配
        best_match_val = -1
        best_match_location = None
        
        best_match_rectangle = None

        # 定义多尺度匹配的缩放范围（缩放倍数）
        if best_match_scale is None:
            scales = np.linspace(0.5, 2.0, 20)  # 从 0.5 到 2 倍进行 20 步缩放
        else:
            scales = [best_match_scale]

        # 在多个缩放级别上进行模板匹配
        for scale in scales:
            # 调整图标尺寸
            scaled_icon = cv2.resize(icon_image, None, fx=scale, fy=scale, interpolation=cv2.INTER_AREA)
            w, h = scaled_icon.shape[1], scaled_icon.shape[0]  # 获取缩放后的宽和高

            # 进行模板匹配
            res = cv2.matchTemplate(large_image, scaled_icon, cv2.TM_CCOEFF_NORMED)

            # 获取匹配结果中最佳匹配的位置和值
            min_val, max_val, min_loc, max_loc = cv2.minMaxLoc(res)

            # 记录最佳匹配
            if max_val > best_match_val:
                best_match_val = max_val
                best_match_location = max_loc
                best_match_scale = scale
                best_match_rectangle = [max_loc, (max_loc[0] + w, max_loc[1] + h)]

        # 在大图上绘制最佳匹配位置的矩形框
        if best_match_rectangle is not None:
            top_left = best_match_rectangle[0]
            bottom_right = best_match_rectangle[1]
            width = bottom_right[0] - top_left[0]
            # 将匹配区域往右移动一个宽度距离
            new_top_left_x = top_left[0] + width
            new_bottom_right_x = bottom_right[0] + 3 * width  # 宽度扩大2倍
            new_top_left_y = top_left[1]
            new_bottom_right_y = bottom_right[1]

            cropped_image = large_image[new_top_left_y:new_bottom_right_y, new_top_left_x:new_bottom_right_x]

            print(f"Best match at location: {best_match_location} with scale: {best_match_scale} and confidence: {best_match_val}")

            # 显示结果
            #cv2.imshow('Matched Image', cropped_image)
            #cv2.waitKey(0)
            #cv2.destroyAllWindows()
            result = reader.readtext(cropped_image,allowlist="0123456789")
            if len(result) > 0:
                ret.append(result[0][1])
            else:
                return []
        else:
            print("No match found.")
            return []
    return ret


if __name__ == "__main__":
    ret = getattrs("test2.jpg")
    print(ret)


import urllib.parse
import httpx, json
from io import BytesIO
import urllib
import os
from pathlib import Path
from PIL import Image
import numpy as np
import cv2
import requests
import urllib3

requests.packages.urllib3.disable_warnings()
try:
    requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += ':HIGH:!DH:!aNULL'
except AttributeError:
    # no pyopenssl support used / needed / available
    pass
try:
    requests.packages.urllib3.contrib.pyopenssl.util.ssl_.DEFAULT_CIPHERS += ':HIGH:!DH:!aNULL'
except AttributeError:
    # no pyopenssl support used / needed / available
    pass

def getpic(__pic_url):
    # 发送 HTTP GET 请求，下载图片
    response = requests.get(__pic_url, verify=False)

    # 检查请求是否成功
    if response.status_code == 200:
        # 将图片内容转换为 NumPy 数组
        image_array = np.asarray(bytearray(response.content), dtype=np.uint8)

        # 使用 OpenCV 将 NumPy 数组解码为图像
        image = cv2.imdecode(image_array, cv2.IMREAD_COLOR)

        # 显示图像
        return image
    else:
        print(f"Failed to download image. Status code: {response.status_code}")
    
    return None

def getpic2(__pic_url):
    current_directory = os.path.dirname(os.path.abspath(__file__))

    image = cv2.imread(os.path.join(current_directory,__pic_url))

    # 显示图像
    return image


if __name__ == "__main__":
    ret = getpic('http://multimedia.nt.qq.com.cn/download?appid=1406&fileid=CgoyNTExNDYyNTA4EhQfVzcAN61BTyouY_v7PhboAGHN_BjJ5Qkg_gooyvuciOLQiAMyBHByb2RQgLsv&spec=0&rkey=CAESKBkcro_MGujokCQEjS-KTYkIVJASmREiXxD3z7jj0Bs6IXK_pGbJH3s')
    print(ret)


#!/usr/bin/env python
#-*- coding:utf-8 -*-


from setuptools import setup, find_packages

with open("README.md","r",encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name = "nonebot_plugin_gakuenImasCalculator",
    version = "0.1.3",
    keywords = ("nonebot","plugin", "gakuenImas", "Calculator","gakuenIdolMaster"),
    description = "NoneBot2学院偶像大师算分插件",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    license = "MIT Licence",

    url = "https://github.com/ikarosf/nonebot_plugin_gakuenImasCalculator",
    author = "ikarosf",
    author_email = "ikarosff@gmail.com",

    packages = find_packages(),
    install_package_data=True,
    include_package_data = True,
    platforms = "any",
    install_requires = ["nonebot2>=2.2.0,<3.0.0" , "opencv-contrib-python>=4.10.0.0" , "opencv-python>=4.10.0.0","easyocr>=1.7.1"]
)